SecureStorage class
Wrapper around FlutterSecureStorage for sensitive data (tokens, secrets).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clearTokens(
) → Future< void> -
containsKey(
String key) → Future< bool> -
delete(
String key) → Future< void> -
deleteAll(
) → Future< void> -
getAccessToken(
) → Future< String?> -
getRefreshToken(
) → Future< String?> -
read(
String key) → Future< String?> -
readAll(
) → Future< Map< String, String> > -
saveAccessToken(
String token) → Future< void> -
saveRefreshToken(
String token) → Future< void> -
write(
String key, String value) → Future< void>