CryptoHelper class

Constructors

CryptoHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(String encryptedBase64) Future<String>
Decrypts text using AES-GCM
encrypt(String plainText) Future<String>
Encrypts text using AES-GCM (Compatible with Android/Swift format: IV + TAG + CIPHERTEXT)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited