ResponsiveValue<T> class

Constructors

ResponsiveValue({required T mobile, T? tablet, T? desktop})
const

Properties

desktop → T?
final
hashCode int
The hash code for this object.
no setterinherited
mobile → T
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablet → T?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(double screenWidth) → T
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited