ScreenSize class

Constructors

ScreenSize()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getScreenType(double width) ScreenType
Get current screen type based on width.
heightPercent(double screenHeight, double percent) double
Get percentage-based height.
responsiveFontSize(double screenWidth, double baseFontSize) double
Get responsive font size based on screen width.
responsiveSpacing(double screenWidth, double baseSpacing) double
Get responsive spacing.
widthPercent(double screenWidth, double percent) double
Get percentage-based width.

Constants

mobileBreakpoint → const double
tabletBreakpoint → const double