Validators class

Common input validators.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

confirmPassword(String? value, String password) String?
email(String? value) String?
minLength(String? value, int length, [String fieldName = 'This field']) String?
password(String? value, {int minLength = 8}) String?
phone(String? value) String?
required(String? value, [String fieldName = 'This field']) String?
url(String? value) String?