ApiController class

Constructors

ApiController()

Properties

currentCall ↔ CancelToken?
getter/setter pair
dio ↔ Dio
latefinal
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelCurrentCall() → void
doGet(String? apiName, OnInterfaceCallbackListener listener, String? apiNamePageRef) → void
doPostMethod(OnInterfaceCallbackListener listener, Map<String, dynamic> passParaMap, String? apiName, String? apiNamePageRef, [String? previousCancelled]) → void
doPostMultipart(OnInterfaceCallbackListener listener, Map<String, dynamic> passParaMap, List<File> fileList, String filesKeyName, String? apiName, String? apiNamePageRef) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited