AppConfig class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- appName → String
-
no setter
- assetPath → String
-
no setter
- baseUrl → String
-
no setter
- bundleId → String
-
no setter
- current → FlavorConfig
-
no setter
- enableCrashReporting → bool
-
no setter
- enableLogging → bool
-
no setter
- isAnalyticsEnabled → bool
-
no setter
- isBiometricAuthEnabled → bool
-
no setter
- isChatEnabled → bool
-
no setter
- isDarkModeEnabled → bool
-
no setter
- isDev → bool
-
no setter
- isNotificationsEnabled → bool
-
no setter
- isPaymentsEnabled → bool
-
no setter
- isProd → bool
-
no setter
- isStaging → bool
-
no setter
Static Methods
-
isFeatureEnabled(
String feature) → bool