EnvConfig class
Constructors
- EnvConfig({required Environment environment, required String baseUrl, bool enableLogging = false, bool enableCrashReporting = false, Duration connectionTimeout = const Duration(seconds: 30), Duration receiveTimeout = const Duration(seconds: 30)})
-
const
- EnvConfig.dev({required String baseUrl})
-
factory
- EnvConfig.prod({required String baseUrl})
-
factory
- EnvConfig.staging({required String baseUrl})
-
factory
Properties
- baseUrl → String
-
final
- connectionTimeout → Duration
-
final
- enableCrashReporting → bool
-
final
- enableLogging → bool
-
final
- environment → Environment
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDev → bool
-
no setter
- isProd → bool
-
no setter
- isStaging → bool
-
no setter
- receiveTimeout → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited