CoreConstants class
Properties
- appLanguage → String
-
no setter
- appLocale → Locale
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRTL → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textDirection → TextDirection
-
no setter
Methods
-
changeLanguage(
String newLanguage) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toggleLanguage(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
translateText(
String key) → String
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- accessTokenKey ↔ String
-
getter/setter pair
- apiBaseUrlKey ↔ String
-
getter/setter pair
- connectTimeoutMs ↔ int?
-
getter/setter pair
- currentFontFamily → String
-
no setter
- defaultLanguage ↔ String
-
getter/setter pair
- encryptionKey ↔ String
-
getter/setter pair
- instance → CoreConstants
-
final
-
languageData
→ Map<
String, dynamic> -
final
- receiveTimeoutMs ↔ int?
-
getter/setter pair
- sendTimeoutMs ↔ int?
-
getter/setter pair